@@ -4,7 +4,7 @@ import shutil
 
 import click
 
-from manati.utils import task, substitute
+from manati.utils import task, substitute, render
 
 
 @task('Create package...', ' OK')
@@ -30,7 +30,16 @@ def add_package(name):
 
 
 def add_license(path, license):
+    """Adds a LICENSE file to specified directory.
 
+    Parameters
+    ----------
+    path: str or pathlib.Path
+        The directory where to put the LICENSE file.
+
+    license: str [MIT|GPLv3|Apache]
+        The type of license.
+    """
     if isinstance(path, str):
         if path == '.' or path == './':
             path = pathlib.Path.cwd()
@@ -56,3 +65,21 @@ def add_license(path, license):
     substitute(setup_py, "license='None'", "license='%s'" % license)
 
 
+def add_github_action(package, tests):
+    cwd = pathlib.Path.cwd()
+    templates = pathlib.Path(__file__).parent / 'templates'
+    if not os.path.exists(cwd / '.github'):
+        os.mkdir(cwd / '.github')
+    if not os.path.exists(cwd / '.github' / 'workflows'):
+        os.mkdir(cwd / '.github' / 'workflows')
+    target = cwd / '.github' / 'workflows' / 'check.yml'
+
+    if os.path.exists(target):
+        if not click.confirm('check.yml already exists. Overwrite?'):
+            click.Abort()
+            return
+
+    render(target, templates / 'check.yml',
+           {':PACKAGE:': package,
+            ':TEST:': tests})
+    click.echo('Created github action under ' + str(target))
